@@ -8,9 +8,34 @@ use Test::Builder;
 use UNIVERSAL::require;
 use Test::Compile::Internal;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 my $Test = Test::Compile::Internal->new();
 
+=head1 NAME
+
+Test::Compile - Check whether Perl files compile correctly.
+
+=head1 SYNOPSIS
+
+    use Test::Compile;
+    all_pm_files_ok();
+
+=head1 DESCRIPTION
+
+C<Test::Compile> lets you check the whether your perl modules and scripts
+compile properly, and report its results in standard C<Test::Simple> fashion.
+
+The basic usage - as shown above, will find all pm files and test that they
+all compile.
+
+You can explicitly specify the list of directories to check, using
+the C<all_pm_files()> function supplied:
+
+    my @pmdirs = qw(blib script);
+    all_pm_files_ok(all_pm_files(@pmdirs));
+
+=cut
+
 sub import {
     my $self   = shift;
     my $caller = caller;
@@ -27,23 +52,119 @@ sub import {
     $Test->plan(@_);
 }
 
+=head1 FUNCTIONS
+
+=over 4
+
+=item C<all_pm_files_ok(@files)>
+
+Checks all the files in C<@files> for compilation. It runs L</all_pm_files()>
+on each file/directory, and calls the C<plan()> function for you (one test for
+each module), so you can't have already called C<plan>.
+
+If C<@files> is empty or not passed, the function finds all Perl module files
+in the F<blib> directory if it exists, or the F<lib> directory if not. A Perl
+module file is one that ends with F<.pm>.
+
+Returns true if all Perl module files are ok, or false if any fail.
+
+Module authors can include the following in a F<t/00_compile.t> file
+and have C<Test::Compile> automatically find and check all Perl module files
+in a module distribution:
+
+    #!perl -w
+    use strict;
+    use warnings;
+    use Test::More;
+    eval "use Test::Compile";
+    Test::More->builder->BAIL_OUT(
+        "Test::Compile required for testing compilation") if $@;
+    all_pm_files_ok();
+
+=cut
+
+sub all_pm_files_ok {
+    my @files = @_ ? @_ : all_pm_files();
+    $Test->plan(tests => scalar @files);
+    my $ok = 1;
+    for (@files) {
+        pm_file_ok($_) or undef $ok;
+    }
+    $ok;
+}
+
+=item C<all_pl_files_ok(@files)>
+
+Checks all the files in C<@files> for compilation. It runs L<pl_file_ok()>
+on each file, and calls the C<plan()> function for you (one test for
+each script), so you can't have already called C<plan>.
+
+If C<@files> is empty or not passed, the function uses all_pl_files() to find
+scripts to test.
+
+Returns true if all Perl module files are ok, or false if any fail.
+
+Module authors can include the following in a F<t/00_compile_scripts.t> file
+and have C<Test::Compile> automatically find and check all Perl script files
+in a module distribution:
+
+    #!perl -w
+    use strict;
+    use warnings;
+    use Test::More;
+    eval "use Test::Compile";
+    plan skip_all => "Test::Compile required for testing compilation"
+      if $@;
+    all_pl_files_ok();
+
+=cut
+
+sub all_pl_files_ok {
+    my @files = @_ ? @_ : all_pl_files();
+    $Test->skip_all("no pl files found") unless @files;
+    $Test->plan(tests => scalar @files);
+    my $ok = 1;
+    for (@files) {
+        pl_file_ok($_) or undef $ok;
+    }
+    $ok;
+}
+
+=item C<pm_file_ok($filename,$testname)>
+
+C<pm_file_ok()> will okay the test if $filename compiles as a perl module.
+
+The optional second argument C<$testname> is the name of the test. If it is
+omitted, C<pm_file_ok()> chooses a default test name C<Compile test for
+$filename>.
+
+=cut
 sub pm_file_ok {
-    my ($file,$name,$verbose) = @_;
+    my ($file,$name) = @_;
 
     $name ||= "Compile test for $file";
 
-    my $old = $Test->verbose();
-    $Test->verbose($verbose);
     my $ok = $Test->pm_file_compiles($file);
-    $Test->verbose($old);
 
     $Test->ok($ok, $name);
     $Test->diag("$file does not compile") unless $ok;
     return $ok;
 }
 
+=item C<pl_file_ok($filename,$testname)>
+
+C<pl_file_ok()> will okay the test if $filename compiles as a perl script. You
+need to give the path to the script relative to this distribution's base
+directory. So if you put your scripts in a 'top-level' directory called script
+the argument would be C<script/filename>.
+
+The optional second argument C<$testname> is the name of the test. If it is
+omitted, C<pl_file_ok()> chooses a default test name C<Compile test for
+$filename>.
+=cut
+
 sub pl_file_ok {
-    my ($file,$name,$verbose) = @_;
+    my ($file,$name) = @_;
 
     $name ||= "Compile test for $file";
 
@@ -61,200 +182,47 @@ sub pl_file_ok {
         }
     }
 
-    my $old = $Test->verbose();
-    $Test->verbose($verbose);
     my $ok = $Test->pl_file_compiles($file);
-    $Test->verbose($old);
 
     $Test->ok($ok, $name);
     $Test->diag("$file does not compile") unless $ok;
     return $ok;
 }
 
-sub all_pm_files_ok {
-    my @files = @_ ? @_ : all_pm_files();
-    $Test->plan(tests => scalar @files);
-    my $ok = 1;
-    for (@files) {
-        pm_file_ok($_) or undef $ok;
-    }
-    $ok;
-}
-
-sub all_pl_files_ok {
-    my @files = @_ ? @_ : all_pl_files();
-    $Test->skip_all("no pl files found") unless @files;
-    $Test->plan(tests => scalar @files);
-    my $ok = 1;
-    for (@files) {
-        pl_file_ok($_) or undef $ok;
-    }
-    $ok;
-}
-
-sub all_pm_files {
-    return $Test->all_pm_files(@_);
-}
-
-sub all_pl_files {
-    return $Test->all_pl_files(@_);
-}
-
-1;
-__END__
-
-=head1 NAME
-
-Test::Compile - Check whether Perl module files compile correctly
-
-=head1 SYNOPSIS
-
-    #!perl -w
-    use strict;
-    use warnings;
-    use Test::Compile;
-    all_pm_files_ok();
-
-=head1 DESCRIPTION
-
-C<Test::Compile> lets you check the whether a Perl module or script file
-compiles properly, and report its results in standard C<Test::Simple> fashion.
-
-    BEGIN {
-        use Test::Compile tests => $num_tests;
-        pm_file_ok($file, "Valid Perl module file");
-    }
-
-It's probably a good idea to run this in a BEGIN block. The examples below
-omit it for clarity.
-
-Module authors can include the following in a F<t/00_compile.t> file and
-have C<Test::Compile> automatically find and check all Perl module files in a
-module distribution:
-
-    use Test::More;
-    eval "use Test::Compile 0.09";
-    Test::More->builder->BAIL_OUT(
-        "Test::Compile 0.09 required for testing compilation") if $@;
-    all_pm_files_ok();
-
-You can also specify a list of files to check, using the
-C<all_pm_files()> function supplied:
-
-    use strict;
-    use Test::More;
-    eval "use Test::Compile 0.09";
-    Test::More->builder->BAIL_OUT(
-        "Test::Compile 0.09 required for testing compilation") if $@;
-    my @pmdirs = qw(blib script);
-    all_pm_files_ok(all_pm_files(@pmdirs));
-
-Or even (if you're running under L<Apache::Test>):
-
-    use strict;
-    use Test::More;
-    eval "use Test::Compile 0.09";
-    Test::More->builder->BAIL_OUT(
-        "Test::Compile 0.09 required for testing compilation") if $@;
-
-    my @pmdirs = qw(blib script);
-    use File::Spec::Functions qw(catdir updir);
-    all_pm_files_ok(
-        all_pm_files(map { catdir updir, $_ } @pmdirs)
-    );
-
-Why do the examples use C<BAIL_OUT()> instead of C<skip_all()>? Because
-testing whether a module compiles is important. C<skip_all()> is ok to use
-with L<Test::Pod>, because if the pod is malformed the program is still going
-to run. But checking whether a module even compiles is something else.
-Test::Compile should be mandatory, not optional.
-
-=head1 FUNCTIONS
-
-=over 4
-
-=item C<pm_file_ok(FILENAME[, TESTNAME ])>
-
-C<pm_file_ok()> will okay the test if the Perl module compiles correctly.
-
-The optional second argument C<TESTNAME> is the name of the test. If it is
-omitted, C<pm_file_ok()> chooses a default test name C<Compile test for
-FILENAME>.
-
-=item C<pl_file_ok(FILENAME[, TESTNAME ])>
-
-C<pl_file_ok()> will okay the test if the Perl script compiles correctly. You
-need to give the path to the script relative to this distribution's base
-directory. So if you put your scripts in a 'top-level' directory called script
-the argument would be C<script/filename>.
-
-The optional second argument C<TESTNAME> is the name of the test. If it is
-omitted, C<pl_file_ok()> chooses a default test name C<Compile test for
-FILENAME>.
-
-=item C<all_pm_files_ok([@files/@directories])>
-
-Checks all the files in C<@files> for compilation. It runs L<all_pm_files()>
-on each file/directory, and calls the C<plan()> function for you (one test for
-each function), so you can't have already called C<plan>.
-
-If C<@files> is empty or not passed, the function finds all Perl module files
-in the F<blib> directory if it exists, or the F<lib> directory if not. A Perl
-module file is one that ends with F<.pm>.
-
-If you're testing a module, just make a F<t/00_compile.t>:
-
-    use Test::More;
-    eval "use Test::Compile 0.09";
-    plan skip_all => "Test::Compile 0.09 required for testing compilation"
-      if $@;
-    all_pm_files_ok();
-
-Returns true if all Perl module files are ok, or false if any fail.
-
-Or you could just let L<Module::Install::StandardTests> do all the work for
-you.
-
-=item C<all_pl_files_ok([@files])>
-
-Checks all the files in C<@files> for compilation. It runs L<pl_file_ok()>
-on each file, and calls the C<plan()> function for you (one test for
-each file), so you can't have already called C<plan>.
-
-If C<@files> is empty or not passed, the function uses all_pl_files() to find
-scripts to test
-
-If you're testing a module, just make a F<t/00_compile_scripts.t>:
-
-    use Test::More;
-    eval "use Test::Compile 0.09";
-    plan skip_all => "Test::Compile 0.09 required for testing compilation"
-      if $@;
-    all_pl_files_ok();
-
-Returns true if all Perl module files are ok, or false if any fail.
-
-=item C<all_pm_files([@dirs])>
+=item C<all_pm_files(@dirs)>
 
 Returns a list of all the perl module files - that is, files ending in F<.pm>
-- in I<$dir> and in directories below. If no directories are passed, it
+- in I<@dirs> and in directories below. If no directories are passed, it
 defaults to F<blib> if F<blib> exists, or else F<lib> if not. Skips any files
 in C<CVS> or C<.svn> directories.
 
 The order of the files returned is machine-dependent. If you want them
 sorted, you'll have to sort them yourself.
 
-=item C<all_pl_files([@files/@dirs])>
+=cut
+
+sub all_pm_files {
+    return $Test->all_pm_files(@_);
+}
+
+=item C<all_pl_files(@dirs)>
 
 Returns a list of all the perl script files - that is, files ending in F<.pl>
 or with no extension. Directory arguments are searched recursively . If
-arguments are passed, it defaults to F<script> if F<script> exists, or else
+I<@dirs> is undefined, it defaults to F<script> if F<script> exists, or else
 F<bin> if F<bin> exists. Skips any files in C<CVS> or C<.svn> directories.
 
 The order of the files returned is machine-dependent. If you want them
 sorted, you'll have to sort them yourself.
 
 =back
+=cut
+
+sub all_pl_files {
+    return $Test->all_pl_files(@_);
+}
+
+1;
 
 =head1 AUTHORS
 
@@ -271,7 +239,12 @@ it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
+L<Test::Compile::Internal> provides an object oriented interface to the
+Test::Compile functionality.
+L<Test::Strict> proveds functions to ensure your perl files comnpile, with
+added bonus that it will check you have used strict in all your files.
 L<Test::LoadAllModules> just handles modules, not script files, but has more
 fine-grained control.
 
+
 =cut
